---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "eventline_jobs Data Source - terraform-provider-eventline"
subcategory: ""
description: |-
  Use this data source to retrieve information about existing eventline jobs.
---

# eventline_jobs (Data Source)

Use this data source to retrieve information about existing eventline jobs.

## Example Usage

```terraform
data "eventline_project" "main" {
  name = "main"
}

data "eventline_jobs" "example" {
  project_id = data.eventline_project.main.id
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `project_id` (String) The identifier of the project the jobs are part of.

### Read-Only

- `elements` (Attributes List) The list of jobs. (see [below for nested schema](#nestedatt--elements))

<a id="nestedatt--elements"></a>
### Nested Schema for `elements`

Read-Only:

- `disabled` (Boolean) Whether the job is disabled or not.
- `id` (String) The identifier of the job.
- `spec` (Attributes) The specification of the job. (see [below for nested schema](#nestedatt--elements--spec))

<a id="nestedatt--elements--spec"></a>
### Nested Schema for `elements.spec`

Read-Only:

- `concurrent` (Boolean) Whether to allow concurrent executions for this job or not.
- `description` (String) A textual description of the job.
- `environment` (Map of String) A set of environment variables mapping names to values to be defined during job execution.
- `identities` (Set of String) Set of eventline identities names to inject during job execution.
- `name` (String) The name of the job.
- `parameters` (Attributes List) (see [below for nested schema](#nestedatt--elements--spec--parameters))
- `retention` (Number) The number of days after which past executions of this job will be deleted. This value override the global job_retention setting.
- `runner` (Attributes) The specification of the runner used to execute the job. (see [below for nested schema](#nestedatt--elements--spec--runner))
- `steps` (Attributes List) A list of steps which will be executed sequentially. (see [below for nested schema](#nestedatt--elements--spec--steps))
- `trigger` (Attributes) The specification of a trigger indicating when to execute the job. (see [below for nested schema](#nestedatt--elements--spec--trigger))

<a id="nestedatt--elements--spec--parameters"></a>
### Nested Schema for `elements.spec.parameters`

Read-Only:

- `description` (String) A textual description of the parameter.
- `environment` (String) The name of an environment variable to be used to inject the value of this parameter during execution.
- `name` (String) The name of the parameter.
- `type` (String) The type of the parameter. The following types are supported:
  - number: Either an integer or an IEEE 754 double precision floating point value.
  - integer: An integer.
  - string: A character string.
  - boolean: A boolean.
- `values` (List of String) For parameters of type string, the list of valid values.


<a id="nestedatt--elements--spec--runner"></a>
### Nested Schema for `elements.spec.runner`

Read-Only:

- `identity` (String) The name of an identity to use for runners which require authentication. For example the ssh runner needs an identity to initiate an ssh connection.
- `name` (String) The name of the runner.


<a id="nestedatt--elements--spec--steps"></a>
### Nested Schema for `elements.spec.steps`

Read-Only:

- `code` (String) The fragment of code to execute for this step.
- `command` (Attributes) The command to execute for this step. (see [below for nested schema](#nestedatt--elements--spec--steps--command))
- `label` (String) A short description of the step which will be displayed on the web interface.
- `script` (Attributes) The command to execute for this step. (see [below for nested schema](#nestedatt--elements--spec--steps--script))

<a id="nestedatt--elements--spec--steps--command"></a>
### Nested Schema for `elements.spec.steps.script`

Read-Only:

- `arguments` (List of String) The list of arguments to pass to the command.
- `name` (String) The name of the command.


<a id="nestedatt--elements--spec--steps--script"></a>
### Nested Schema for `elements.spec.steps.script`

Read-Only:

- `arguments` (List of String) The list of arguments to pass to the command.
- `content` (String) The script file contents.
- `path` (String) The path of the script file relative to the job file.



<a id="nestedatt--elements--spec--trigger"></a>
### Nested Schema for `elements.spec.trigger`

Read-Only:

- `event` (String) The event to react to formatted as <connector>/<event>.
- `identity` (String) The name of an identity to use for events which require authentication. For example the github/push event needs an identity to create the GitHub hook used to listen to push events.
